@@ -3,6 +3,7 @@ import matplotlib.pyplot as plt
 import h5py
 from .utils import plotJV, getChunk, getJVparams
 from datetime import datetime
+import itertools
 RTYPES = ["JV","LIGHT","CV","CC","MPP"]
     
 class Result:
@@ -18,7 +19,15 @@ class Result:
         for x in self.f['Results']['samples']:
             name = self.f['Results']['samples'][x].attrs['name']
             self.samples[name] = x
-            
+    
+    def getResultsByType(self, sample, res_type):
+        return [i for i,x in enumerate(self.getResultsTypes(sample)) if x==res_type]
+        
+    def getStartStopData(self, sample, result_id):
+        tc = self.getResultTimestamp(sample, result_id, raw=True)
+        r = self.__getSample(sample)['results'][tc]['data']
+        return {x:(r.attrs['start_values'][i],r.attrs['stop_values'][i],r.attrs['units'][i]) for i,x in enumerate(r.attrs['name'])}
+    
     def getSampleList(self):
         """
         get a list of all samples present in the result.
@@ -72,8 +81,13 @@ class Result:
         s = self.__getSample(sample)['results']
         R = s.get(str(self.getResultTimestamp(sample, resultID, raw=True)))
         time = np.array(R['1']['time'])
-        names = list(R['1']['variables'])
-        return [[x.decode("ansi") for x in n] for n in names]
+        if 'variables' in R['1']:
+            names = [[x.decode("ansi") for x in n] for n in list(R['1']['variables'])]
+        else:
+            keys = [x[4:] for x in R['1'].keys() if x[:4]=='data']
+            keys.sort()
+            names = [[R['1']['data'+x].attrs[v] for v in ['name','unit']] for x in keys]
+        return names
         
     def getSensorResultByName(self, sample, resultID, sensor_name):
         """
@@ -153,15 +167,30 @@ class Result:
                     return {'type':"JV",'voltage':V,'current':I,"params":getJVparams(V,I)}
         elif R.attrs["type"] in [2,3,4]:
             t = np.array(R['0']['time'])
-            data = np.array(R['0']['data'])
+            if 'data' in R['0'].keys():
+                data = np.array(R['0']['data'])
+            else:
+                keys = [x[4:] for x in R['0'].keys() if x[:4]=='data']
+                keys.sort()
+                data = np.stack([np.array(R['0']['data'+x]) for x in keys])
             V = data[0,pixelID,:]
             I = data[1,pixelID,:]
             if includeSensors:
-                sens = {
-                    't': np.array(R['1']['time']),
-                    'name': list(R['1']['variables']),
-                    'data':np.array(R['1']['data'])
-                    }
+                keys = [x[4:] for x in R['1'].keys() if x[:4]=='data']
+                keys.sort()
+                if 'data' in R['1'].keys():
+                    sens = {
+                        't': np.array(R['1']['time']),
+                        'name': list(R['1']['variables']),
+                        'data':np.array(R['1']['data'])
+                        }
+                else:
+                    sens = sens = {
+                        't': np.array(R['1']['time']),
+                        'sensors' : {R['1']['data'+x].attrs["name"]:{
+                            'unit':R['1']['data'+x].attrs["unit"],
+                            'data': np.ravel(R['1']['data'+x])} for x in keys}
+                        }
                 return {'type':"Stress", 't':t,'voltage':V,'current':I,'start_time':R.attrs.get("start_time"),"sensors":sens}
             return {'type':"Stress", 't':t,'voltage':V,'current':I,'start_time':R.attrs.get("start_time")}
     
